|Build Status|

|PyPI version|

|Coverage Status|

EvoDAG
======

Evolving Directed Acyclic Graph (EvoDAG) is a steady-state Genetic
Programming system with tournament selection.

More information can be found on http://github.com/mgraffg/EvoDAG
